import Vue from 'vue'
import Router from 'vue-router'


Vue.use(Router)
/**
 * Note: 路由配置项
 * name:'router-name'             // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    keepAlive: true              // 如果设置为true，则会被 <keep-alive> 缓存 (默认 false)
    title: 'title'               // 设置该路由在页面顶部的Title
    index: '1'                   // 设置该路由页面切换是否左右滑动及权重，如不设页面不滑动  PS：功能暂时未启用
    hidden: true                 // 如果设置为true，显示底部菜单，如不设或者false，不显示
  }
 */
export const constantRoutes = [
  {
    path: '/',
    redirect: '/index'
  },
  {
    path: '/index',
    name: 'index',
    meta: {
      title: '主页',
      keepAlive: true
    },
    component: (resolve) => require(['@/views/index'], resolve)
  },
  {
    path: '/login',
    name: 'login',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/login'], resolve)
  },
  {
    path: '/register',
    name: 'register',
    meta: {
      title: '注册页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register'], resolve)
  },
  {
    path: '/document',
    name: 'document',
    meta: {
      title: '文档',
    },
    component: (resolve) => require(['@/views/document'], resolve)
  },
  {
    path: '/workbench',
    name: 'workbench',
    meta: {
      title: '工作台'
    },
    component: (resolve) => require(['@/views/workbench'], resolve)
  },
  {
    path: '/addressBook',
    name: 'addressBook',
    meta: {
      title: '通讯录'
    },
    component: (resolve) => require(['@/views/addressBook'], resolve)
  },
  {
    path: '/mynsgk',
    name: 'mynsgk',
    meta: {
      title: '我的'
    },
    component: (resolve) => require(['@/views/mynsgk'], resolve)
  } ,
  {
    path: '/authenticRight',
    name: 'authenticRight',
    meta: {
      title: '确权颁证调查统计表',
    },
    component: (resolve) => require(['@/views/authenticRight/index'], resolve)
  },
  {
    path: '/biddingHall',
    name: 'biddingHall',
    meta: {
      title: '竞价大厅',
      hidden: true,
    },
    component: (resolve) => require(['@/views/biddingHall'], resolve)
  },
  {
    path: '/project',
    name: 'project',
    meta: {
      title: '挂牌项目'
    },
    component: (resolve) => require(['@/views/project'], resolve)
  },
  {
    path: '/project/projectDetail',
    name: 'projectDetail',
    meta: {
      title: '挂牌项目',
      hidden: true
    },
    component: (resolve) => require(['@/views/project/projectDetail'], resolve)
  },
  {
    path: '/news/index',
    name: 'news',
    meta: {
      title: '新闻资讯',
      hidden: true,
    },
    component: (resolve) => require(['@/views/news/index'], resolve)
  },
  {
    path: '/news/newDetail',
    name: 'newDetail',
    meta: {
      title: '新闻详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/news/newDetail'], resolve)
  },
  {
    path: '/notice/index',
    name: 'notice',
    meta: {
      title: '项目公告',
      hidden: true,
    },
    component: (resolve) => require(['@/views/notice/index'], resolve)
  },
  {
    path: '/supply/index',
    name: 'supply',
    meta: {
      title: '个人供求',
      hidden: true,
    },
    component: (resolve) => require(['@/views/supply/index'], resolve)
  },
  {
    path: '/interaction/index',
    name: 'interaction',
    meta: {
      title: '互动交流',
      hidden: true,
    },
    component: (resolve) => require(['@/views/interaction/index'], resolve)
  },
  {
    path: '/register/index',
    name: 'registerAgreement',
    meta: {
      title: '注册须知',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/index'], resolve)
  },
  {
    path: '/register/registerType',
    name: 'registerType',
    meta: {
      title: '注册类型',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/registerType'], resolve)
  },
  {
    path: '/register/userRegister',
    name: 'userRegister',
    meta: {
      title: '个人用户注册',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/userRegister'], resolve)
  },
  {
    path: '/register/companyRegister',
    name: 'companyRegister',
    meta: {
      title: '单位用户注册',
      hidden: true,
    },
    component: (resolve) => require(['@/views/register/companyRegister'], resolve)
  },
  {
    path: '/user',
    name: 'user',
    meta: {
      title: '个人中心',
    },
    component: (resolve) => require(['@/views/user/index'], resolve)
  },
  {
    path: '/accountSetting',
    name: 'accountSetting',
    meta: {
      title: '账户设置',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/index'], resolve)
  },
  {
    path: '/companyInformation',
    name: 'companyInformation',
    meta: {
      title: '资料修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/userInformation/companyInformation'], resolve)
  },
  {
    path: '/userInformation',
    name: 'userInformation',
    meta: {
      title: '资料修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/userInformation/userInformation'], resolve)
  },
  {
    path: '/bankInformation',
    name: 'bankInformation',
    meta: {
      title: '银行账户修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/bankInformation/index'], resolve)
  },
  {
    path: '/phoneInformation',
    name: 'phoneInformation',
    meta: {
      title: '手机号修改',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/accountSetting/phoneInformation/index'], resolve)
  },
  {
    path: '/bidding',
    name: 'bidding',
    meta: {
      title: '我的竞价',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/bidding/index'], resolve)
  },
  {
    path: '/userInteraction',
    name: 'userInteraction',
    meta: {
      title: '我的咨询',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/interaction/index'], resolve)
  },
  {
    path: '/userSupply',
    name: 'userSupply',
    meta: {
      title: '我的供求',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/supply/index'], resolve)
  },
  {
    path: '/policy',
    name: 'policy',
    meta: {
      title: '政策法规',
      hidden: true,
    },
    component: (resolve) => require(['@/views/policy/index'], resolve)
  },
  {
    path: '/project/signUp',
    name: 'signUp',
    meta: {
      title: '报名',
      hidden: true
    },
    component: (resolve) => require(['@/views/project/signUp'], resolve)
  },
  {
    path: '/noticeDetail',
    name: 'noticeDetail',
    meta: {
      title: '公告详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/notice/noticeDetail'], resolve)
  },
  {
    path: '/attestationDetail',
    name: 'attestationDetail',
    meta: {
      title: '鉴证详情',
      hidden: true,
    },
    component: (resolve) => require(['@/views/notice/attestationDetail'], resolve)
  },
  {
    path: '/policyDetail',
    name: 'policyDetail',
    meta: {
      title: '政策法规',
      hidden: true,
    },
    component: (resolve) => require(['@/views/policy/policyDetail'], resolve)
  },
  {
    path: '/interactionAdd',
    name: 'interactionAdd',
    meta: {
      title: '添加互动交流',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/interaction/interactionAdd'], resolve)
  },
  {
    path: '/supplyAdd',
    name: 'supplyAdd',
    meta: {
      title: '添加互动交流',
      hidden: true,
    },
    component: (resolve) => require(['@/views/user/supply/supplyAdd'], resolve)
  },
  //两清三化宅基地
  {
    path: '/homestead/index',
    name: 'homesteadIndex',
    meta: {
      title: '两清三化宅基地',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homestead/index'], resolve)
  },
  {
    path: '/homestead/login',
    name: 'homesteadLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/homestead/login'], resolve)
  },
//两清三化宅基地
  {
    path: '/authenticRight/index',
    name: 'authenticRightIndex',
    meta: {
      title: '两清三化宅基地',
      hidden: true,
    },
    component: (resolve) => require(['@/views/authenticRight/index'], resolve)
  },
  {
    path: '/authenticRight/login',
    name: 'authenticRightLogin',
    meta: {
      title: '登录页',
      hidden: true,
    },
    component: (resolve) => require(['@/views/authenticRight/login'], resolve)
  }


];


export default new Router({
  linkActiveClass: 'active',
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
